# Pesquisa e Enriquecimento

## Quality Gate

- Informação pesquisada é relevante para a demanda
- Fontes são confiáveis
- Resultado é resumido e objetivo

## Veto Conditions

- Informação fabricada ou sem fonte
- Pesquisa irrelevante para o contexto doméstico
